DeveloperWalletsClient

Struct DeveloperWalletsClient 

pub struct DeveloperWalletsClient { /* private fields */ }
Async HTTP client for the Circle W3S Developer-Controlled Wallets API.

Implementations

Source

impl DeveloperWalletsClient

pub fn new(api_key: impl Into<String>) -> Self

Creates a new client using the Circle production base URL.

pub fn with_base_url( api_key: impl Into<String>, base_url: impl Into<String>, ) -> Self

Creates a new client with a custom base URL (useful for Prism mock servers).

pub async fn create_wallet_set( &self, req: &CreateWalletSetRequest, ) -> Result<WalletSetResponse, Error>

Create a new developer-controlled wallet set.

pub async fn get_wallet_set(&self, id: &str) -> Result<WalletSetResponse, Error>

Get a wallet set by its UUID.

pub async fn update_wallet_set( &self, id: &str, req: &UpdateWalletSetRequest, ) -> Result<WalletSetResponse, Error>

Update the name of a wallet set.

pub async fn list_wallet_sets( &self, params: &ListWalletSetsParams, ) -> Result<WalletSets, Error>

List all wallet sets belonging to the entity.

pub async fn create_wallets( &self, req: &CreateWalletsRequest, ) -> Result<Wallets, Error>

Create one or more developer-controlled wallets.

pub async fn list_wallets( &self, params: &ListWalletsParams, ) -> Result<Wallets, Error>

List wallets matching the given filters.

pub async fn get_wallet(&self, id: &str) -> Result<WalletResponse, Error>

Get a wallet by its UUID.

pub async fn update_wallet( &self, id: &str, req: &UpdateWalletRequest, ) -> Result<WalletResponse, Error>

Update the name or reference ID of a wallet.

pub async fn list_wallet_balances( &self, params: &ListWalletBalancesParams, ) -> Result<WalletsWithBalances, Error>

List developer wallets with their token balances.

pub async fn list_wallet_token_balances( &self, wallet_id: &str, params: &WalletNftsParams, ) -> Result<Balances, Error>

Retrieve token balances for a single wallet by its UUID.

pub async fn list_wallet_nfts( &self, wallet_id: &str, params: &ListWalletNftsParams, ) -> Result<Nfts, Error>

Retrieve NFTs held by a wallet by its UUID.

pub async fn sign_message( &self, req: &SignMessageRequest, ) -> Result<SignatureResponse, Error>

Sign a plain or hex-encoded message.

pub async fn sign_typed_data( &self, req: &SignTypedDataRequest, ) -> Result<SignatureResponse, Error>

Sign an EIP-712 typed data payload.

pub async fn sign_transaction( &self, req: &SignTransactionRequest, ) -> Result<SignTransactionResponse, Error>

Sign a raw transaction.

pub async fn list_transactions( &self, params: &ListTransactionsParams, ) -> Result<Transactions, Error>

List transactions matching the given filters.

pub async fn get_transaction( &self, id: &str, ) -> Result<TransactionResponse, Error>

Get a transaction by its UUID.

pub async fn create_transfer_transaction( &self, req: &CreateTransferTxRequest, ) -> Result<TransactionResponse, Error>

Create a developer-controlled transfer transaction.

pub async fn get_fee_parameters( &self, req: &CreateTransferTxRequest, ) -> Result<EstimateFeeResponse, Error>

Get fee parameters for a transfer.

pub async fn create_contract_execution_transaction( &self, req: &CreateContractExecutionTxRequest, ) -> Result<TransactionResponse, Error>

Create a developer-controlled contract execution transaction.

pub async fn cancel_transaction( &self, id: &str, req: &CancelTxRequest, ) -> Result<TransactionResponse, Error>

Cancel a stuck or queued transaction.

pub async fn accelerate_transaction( &self, id: &str, req: &AccelerateTxRequest, ) -> Result<TransactionResponse, Error>

Accelerate a stuck transaction by resubmitting with higher fees.

pub async fn get_token(&self, id: &str) -> Result<TokenResponse, Error>

Get a token by its UUID.

pub async fn estimate_transfer_fee( &self, req: &EstimateTransferFeeRequest, ) -> Result<EstimateFeeResponse, Error>

Estimate fees for a transfer transaction.

pub async fn validate_address( &self, req: &ValidateAddressRequest, ) -> Result<ValidateAddressResponse, Error>

Validate a blockchain address.